@@ -2,10 +2,10 @@ package Net::DNS::DomainName;
 use base qw(Net::DNS::Domain);
 
 #
-# $Id: DomainName.pm 953 2011-11-02 21:15:28Z willem $
+# $Id: DomainName.pm 1068 2012-12-06 10:38:51Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 953 $)[1];
+$VERSION = (qw$LastChangedRevision: 1068 $)[1];
 
 
 =head1 NAME
@@ -182,14 +182,14 @@ sub encode {
 	while (@labels) {
 		my $name = join( '.', @labels );
 
-		return $data . pack( 'n', $hash->{$name} ) if defined $hash->{$name};
+		return $data . pack( 'n', 0xC000 | $hash->{$name} ) if defined $hash->{$name};
 
 		my $label  = shift @labels;
 		my $length = length $label;
 		$data .= pack( 'C a*', $length, $label );
 
 		next unless $offset < 0x4000;
-		$hash->{$name} = 0xC000 | $offset;
+		$hash->{$name} = $offset;
 		$offset += 1 + $length;
 	}
 	$data .= chr(0);
@@ -197,9 +197,9 @@ sub encode {
 
 
 sub _lc {
-	local $_ = shift;
-	tr [\101-\132] [\141-\172];
-	return $_;
+	my $s = shift;
+	$s =~ tr [\101-\132] [\141-\172];
+	return $s;
 }
 
 
@@ -247,9 +247,9 @@ sub encode {
 
 
 sub _lc {
-	local $_ = shift;
-	tr [\101-\132] [\141-\172];
-	return $_;
+	my $s = shift;
+	$s =~ tr [\101-\132] [\141-\172];
+	return $s;
 }
 
 
