@@ -1,10 +1,11 @@
 package Net::DNS::Mailbox;
+use base qw(Net::DNS::DomainName);
 
 #
-# $Id: Mailbox.pm 1150 2014-01-02 20:17:17Z willem $
+# $Id: Mailbox.pm 1068 2012-12-06 10:38:51Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1150 $)[1];
+$VERSION = (qw$LastChangedRevision: 1068 $)[1];
 
 
 =head1 NAME
@@ -27,11 +28,8 @@ objects representing the DNS coded form of RFC822 mailbox address.
 
 
 use strict;
-use integer;
 use Carp;
 
-use base qw(Net::DNS::DomainName);
-
 
 =head1 METHODS
 
@@ -61,6 +59,8 @@ sub new {
 
 	my ( $mbox, @host ) = split /\@/;			# split on @ if present
 	for ( $mbox ||= '' ) {
+		s/\\\s/\\032/g;					# disguise escaped white space
+		s/^(".*)\s+(.*")/$1\\032$2/g;			# disguise quoted white space
 		s/^"(.*)"/$1/;					# strip quotes
 		s/\\\./\\046/g;					# disguise escaped dot
 		s/\./\\046/g if @host;				# escape dots in local part
@@ -101,20 +101,20 @@ canonicalisation.
 =cut
 
 package Net::DNS::Mailbox1035;
-
-use Net::DNS::DomainName;
-use base qw(Net::DNS::DomainName1035 Net::DNS::Mailbox);
+use base qw(Net::DNS::DomainName1035);
 
 sub new { &Net::DNS::Mailbox::new; }
 
+sub address { &Net::DNS::Mailbox::address; }
+
 
 package Net::DNS::Mailbox2535;
-
-use Net::DNS::DomainName;
-use base qw(Net::DNS::DomainName2535 Net::DNS::Mailbox);
+use base qw(Net::DNS::DomainName2535);
 
 sub new { &Net::DNS::Mailbox::new; }
 
+sub address { &Net::DNS::Mailbox::address; }
+
 
 1;
 __END__
