@@ -1,14 +1,12 @@
 package Net::DNS::RR::LP;
 
 #
-# $Id: LP.pm 1188 2014-04-03 18:54:34Z willem $
+# $Id: LP.pm 1068 2012-12-06 10:38:51Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1188 $)[1];
+$VERSION = (qw$LastChangedRevision: 1068 $)[1];
 
-
-use strict;
-use base qw(Net::DNS::RR);
+use base Net::DNS::RR;
 
 =head1 NAME
 
@@ -17,6 +15,7 @@ Net::DNS::RR::LP - DNS LP resource record
 =cut
 
 
+use strict;
 use integer;
 
 
@@ -25,7 +24,7 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 	my ( $data, $offset ) = @_;
 
 	$self->{preference} = unpack( "\@$offset n", $$data );
-	$self->{locator} = decode Net::DNS::DomainName( $data, $offset + 2 );
+	$self->{locator} = decode Net::DNS::DomainName($data,$offset+2 );
 }
 
 
@@ -49,38 +48,40 @@ sub format_rdata {			## format rdata portion of RR string.
 sub parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
-	$self->preference(shift);
-	$self->locator(shift);
+	$self->$_(shift) for qw(preference locator);
 }
 
 
 sub preference {
 	my $self = shift;
 
-	$self->{preference} = 0 + shift if scalar @_;
-	return $self->{preference} || 0;
+	$self->{preference} = shift if @_;
+	return 0 + ( $self->{preference} || 0 );
 }
 
-
 sub locator {
 	my $self = shift;
 
-	$self->{locator} = new Net::DNS::DomainName(shift) if scalar @_;
+	$self->{locator} = new Net::DNS::DomainName(shift) if @_;
 	$self->{locator}->name if defined wantarray;
 }
 
-
 sub fqdn { &locator; }
 
-
-__PACKAGE__->set_rrsort_func(		## sort RRs in numerically ascending order.
+__PACKAGE__->set_rrsort_func(				## sort RRs in numerically ascending order.
 	'preference',
-	sub { $Net::DNS::a->{'preference'} <=> $Net::DNS::b->{'preference'} }
+	sub {
+		my ( $a, $b ) = ( $Net::DNS::a, $Net::DNS::b );
+		$a->{preference} <=> $b->{preference};
+	} );
+
+
+__PACKAGE__->set_rrsort_func(
+	'default_sort',
+	__PACKAGE__->get_rrsort_func('preference')
 
 	);
 
-__PACKAGE__->set_rrsort_func( 'default_sort', __PACKAGE__->get_rrsort_func('preference') );
-
 1;
 __END__
 
@@ -94,7 +95,7 @@ __END__
 	name	   => 'example.com',
 	type	   => 'LP',
 	preference => 10,
-	locator	   => 'locator.example.com'
+	locator    => 'locator.example.com'
 	);
 
 =head1 DESCRIPTION
@@ -119,7 +120,6 @@ other unpredictable behaviour.
 =head2 preference
 
     $preference = $rr->preference;
-    $rr->preference( $preference );
 
 A 16 bit unsigned integer in network byte order that indicates the
 relative preference for this LP record among other LP records
@@ -129,7 +129,6 @@ higher values.
 =head2 locator
 
     $locator = $rr->locator;
-    $rr->locator( $locator );
 
 The Locator field contains the DNS target name that is used to
 reference L32 and/or L64 records.
@@ -139,13 +138,13 @@ reference L32 and/or L64 records.
 
 Copyright (c)2012 Dick Franks.
 
+Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
+
 All rights reserved.
 
 This program is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
 
-Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
-
 
 =head1 SEE ALSO
 
