@@ -1,15 +1,15 @@
 package Net::DNS::RR::MB;
 #
-# $Id: MB.pm 388 2005-06-22 10:06:05Z olaf $
+# $Id: MB.pm 1068 2012-12-06 10:38:51Z willem $
 #
 use strict;
-BEGIN { 
+BEGIN {
     eval { require bytes; }
-} 
+}
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$LastChangedRevision: 388 $)[1];
+$VERSION = (qw$LastChangedRevision: 1068 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -25,8 +25,7 @@ sub new_from_string {
 	my ($class, $self, $string) = @_;
 
 	if ($string) {
-		$string =~ s/\.+$//;
-		$self->{"madname"} = $string;
+		$self->{"madname"} = Net::DNS::stripdot($string);
 	}
 
 	return bless $self, $class;
@@ -49,11 +48,20 @@ sub rr_rdata {
 	return $rdata;
 }
 
+
+sub _normalize_dnames {
+	my $self=shift;
+	$self->_normalize_ownername();
+	$self->{"madname"}=Net::DNS::stripdot($self->{"madname"}) if defined $self->{"madname"};
+}
+
+
+
 sub _canonicalRdata {
     my $self=shift;
     my $rdata = "";
     if (exists $self->{"madname"}) {
-		$rdata .= $self->_name2wire($self->{"madname"});
+		$rdata .= $self->_name2wire(lc($self->{"madname"}));
 	}
 	return $rdata;
 }
@@ -84,7 +92,7 @@ Returns the domain name of the host which has the specified mailbox.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2002 Michael Fuhr. 
+Copyright (c) 1997-2002 Michael Fuhr.
 
 Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
