@@ -1,15 +1,15 @@
 package Net::DNS::RR::MG;
 #
-# $Id: MG.pm 632 2007-03-12 13:24:21Z olaf $
+# $Id: MG.pm 1068 2012-12-06 10:38:51Z willem $
 #
 use strict;
-BEGIN { 
+BEGIN {
     eval { require bytes; }
-} 
+}
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$LastChangedRevision: 632 $)[1];
+$VERSION = (qw$LastChangedRevision: 1068 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -17,7 +17,7 @@ sub new {
 	if ($self->{"rdlength"} > 0) {
 		($self->{"mgmname"}) = Net::DNS::Packet::dn_expand($data, $offset);
 	}
-	
+
 	return bless $self, $class;
 }
 
@@ -25,8 +25,7 @@ sub new_from_string {
 	my ($class, $self, $string) = @_;
 
 	if ($string) {
-		$string =~ s/\.+$//;
-		$self->{"mgmname"} = $string;
+		$self->{"mgmname"} = Net::DNS::stripdot($string);
 	}
 
 	return bless $self, $class;
@@ -50,6 +49,13 @@ sub rr_rdata {
 }
 
 
+sub _normalize_dnames {
+	my $self=shift;
+	$self->_normalize_ownername();
+	$self->{'mgmname'}=Net::DNS::stripdot($self->{'mgmname'}) if defined $self->{'mgmname'};
+}
+
+
 sub _canonicalRdata {
     my $self=shift;
     my $rdata = "";
@@ -85,7 +91,7 @@ Returns the RR's mailbox field.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2002 Michael Fuhr. 
+Copyright (c) 1997-2002 Michael Fuhr.
 
 Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
