@@ -1,15 +1,15 @@
 package Net::DNS::RR::MR;
 #
-# $Id: MR.pm 632 2007-03-12 13:24:21Z olaf $
+# $Id: MR.pm 1068 2012-12-06 10:38:51Z willem $
 #
 use strict;
-BEGIN { 
+BEGIN {
     eval { require bytes; }
-} 
+}
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$LastChangedRevision: 632 $)[1];
+$VERSION = (qw$LastChangedRevision: 1068 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -25,8 +25,8 @@ sub new_from_string {
 	my ($class, $self, $string) = @_;
 
 	if ($string) {
-		$string =~ s/\.+$//;
-		$self->{"newname"} = $string;
+
+		$self->{"newname"} = Net::DNS::stripdot($string);
 	}
 
 	return bless $self, $class;
@@ -49,6 +49,17 @@ sub rr_rdata {
 	return $rdata;
 }
 
+
+
+sub _normalize_dnames {
+	my $self=shift;
+	$self->_normalize_ownername();
+	$self->{'newname'}=Net::DNS::stripdot($self->{'newname'}) if defined $self->{'newname'};
+
+
+}
+
+
 sub _canonicalRdata {
     my $self=shift;
     my $rdata = "";
@@ -85,7 +96,7 @@ Returns the RR's new name field.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2002 Michael Fuhr. 
+Copyright (c) 1997-2002 Michael Fuhr.
 
 Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
