@@ -1,15 +1,15 @@
 package Net::DNS::RR::NSAP;
 #
-# $Id: NSAP.pm 388 2005-06-22 10:06:05Z olaf $
+# $Id: NSAP.pm 1068 2012-12-06 10:38:51Z willem $
 #
 use strict;
-BEGIN { 
+BEGIN {
     eval { require bytes; }
-} 
+}
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$LastChangedRevision: 388 $)[1];
+$VERSION = (qw$LastChangedRevision: 1068 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -63,20 +63,20 @@ sub new {
 
 sub new_from_string {
 	my ($class, $self, $string) = @_;
-	
+
 	if ($string) {
 		$string =~ s/\.//g;  # remove all dots.
 		$string =~ s/^0x//;  # remove leading 0x
-		
+
 		if ($string =~ /^[a-zA-Z0-9]{40}$/) {
-			@{ $self }{ qw(afi idi dfi aa rsvd rd area id sel) } = 
+			@{ $self }{ qw(afi idi dfi aa rsvd rd area id sel) } =
 				unpack("A2A4A2A6A4A4A4A12A2", $string);
-		} 
+		}
 	}
-	
+
 	return bless $self, $class;
 }
-	
+
 
 sub idp {
 	my $self = shift;
@@ -88,7 +88,7 @@ sub idp {
 sub dsp {
 	my $self = shift;
 
-	return join('', 
+	return join('',
 			 $self->{"dfi"},
 			 $self->{"aa"},
 			 $self->rsvd,
@@ -110,7 +110,7 @@ sub rdatastr {
 
 	if (exists $self->{"afi"}) {
 		if ($self->{"afi"} eq "47") {
-			$rdatastr = join('', $self->idp, $self->dsp);
+			$rdatastr = "0x".join('.', $self->idp, $self->dsp);
 		} else {
 			$rdatastr = "; AFI $self->{'afi'} not supported";
 		}
@@ -220,13 +220,13 @@ Returns the RR's initial domain identifier.
 
 Returns the RR's DSP format identifier.
 
-=head2 aa 
+=head2 aa
 
     print "aa = ", $rr->aa, "\n";
 
 Returns the RR's administrative authority.
 
-=head2 rsvd 
+=head2 rsvd
 
     print "rsvd = ", $rr->rsvd, "\n";
 
@@ -256,14 +256,17 @@ Returns the RR's system identifier.
 
 Returns the RR's NSAP selector.
 
+=head1 NOTE
+
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2002 Michael Fuhr. 
+Copyright (c) 1997-2002 Michael Fuhr.
 
 Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
+
 All rights reserved.  This program is free software; you may redistribute
-it and/or modify it under the same terms as Perl itself.. 
+it and/or modify it under the same terms as Perl itself..
 
 =head1 SEE ALSO
 
