@@ -1,55 +1,73 @@
 package Net::DNS::Resolver;
+
 #
-# $Id: Resolver.pm 830 2009-12-23 16:31:13Z olaf $
+# $Id: Resolver.pm 1068 2012-12-06 10:38:51Z willem $
 #
-
-use strict;
-use vars qw($VERSION @ISA);
-
-$VERSION = (qw$LastChangedRevision: 830 $)[1];
-
-BEGIN {
-	if ($^O eq 'MSWin32') {
-		require Net::DNS::Resolver::Win32;
-		@ISA = qw(Net::DNS::Resolver::Win32);
-	} elsif ($^O eq 'cygwin') {
-		require Net::DNS::Resolver::Win32;
-		@ISA = qw(Net::DNS::Resolver::Win32);
-	} else {   
-		require Net::DNS::Resolver::UNIX;
-		@ISA = qw(Net::DNS::Resolver::UNIX);
-	}
-}
-
-__PACKAGE__->init();
-
-1;
-
-__END__
+use vars qw($VERSION);
+$VERSION = (qw$LastChangedRevision: 1068 $)[1];
 
 =head1 NAME
 
 Net::DNS::Resolver - DNS resolver class
 
+=cut
+
+
+use strict;
+
+use vars qw(@ISA);
+
+BEGIN {
+	for ($^O) {				## Perl OS identifier
+
+		/cygwin/ && do {
+			eval { require Net::DNS::Resolver::MSWin32; };
+
+			unless ($@) {
+				@ISA = qw(Net::DNS::Resolver::MSWin32);
+				last;
+			}
+		};
+
+
+		eval "require Net::DNS::Resolver::$_;";
+
+		unless ($@) {
+			@ISA = ("Net::DNS::Resolver::$_");
+		} else {
+			require Net::DNS::Resolver::UNIX;
+			@ISA = qw(Net::DNS::Resolver::UNIX);
+		}
+	}
+}
+
+__PACKAGE__->init();
+
+
+1;
+
+__END__
+
+
 =head1 SYNOPSIS
 
   use Net::DNS;
-  
+
   my $res = Net::DNS::Resolver->new;
-  
+
   # Perform a lookup, using the searchlist if appropriate.
   my $answer = $res->search('example.com');
-  
+
   # Perform a lookup, without the searchlist
   my $answer = $res->query('example.com', 'MX');
-  
+
   # Perform a lookup, without pre or post-processing
   my $answer = $res->send('example.com', 'MX', 'CH');
-  
+
   # Send a prebuilt packet
   my $packet = Net::DNS::Packet->new(...);
   my $answer = $res->send($packet);
-  
+
 =head1 DESCRIPTION
 
 Instances of the C<Net::DNS::Resolver> class represent resolver objects.
@@ -63,10 +81,10 @@ recursion is desired, etc.
 
   # Use the system defaults
   my $res = Net::DNS::Resolver->new;
-  
+
   # Use my own configuration file
   my $res = Net::DNS::Resolver->new(config_file => '/my/dns.conf');
-  
+
   # Set options in the constructor
   my $res = Net::DNS::Resolver->new(
   	nameservers => [qw(10.1.1.128 10.1.2.128)],
@@ -75,7 +93,7 @@ recursion is desired, etc.
   );
 
 Returns a resolver object.  If given no arguments, C<new()> returns an
-object configured to your system's defaults.  On UNIX systems the 
+object configured to your system's defaults.  On UNIX systems the
 defaults are read from the following files, in the order indicated:
 
     /etc/resolv.conf
@@ -112,7 +130,7 @@ dynamically configured network interfaces may confuse Net::DNS.
 You can include a configuration file of your own when creating a
 resolver object:
 
- # Use my own configuration file 
+ # Use my own configuration file
  my $res = Net::DNS::Resolver->new(config_file => '/my/dns.conf');
 
 This is supported on both UNIX and Windows.  Values pulled from a custom
@@ -127,7 +145,7 @@ arguments to new() are supported:
 
 =item nameservers
 
-An array reference of nameservers to query.  
+An array reference of nameservers to query.
 
 =item searchlist
 
@@ -239,7 +257,7 @@ any answers or not, use the send() method instead.
     $packet = $res->send('user.passwd.example.com', 'TXT', 'HS');
 
 Performs a DNS query for the given name.  Neither the searchlist
-nor the default domain will be appended.  
+nor the default domain will be appended.
 
 The argument list can be either a C<Net::DNS::Packet> object or a list
 of strings.  The record type and class can be omitted; they default to
@@ -322,8 +340,14 @@ See also L</axfr>.
 
 Gets or sets the nameservers to be queried.
 
-Also see the IPv6 transport notes below    
+Also see the IPv6 transport notes below
 
+=head2 empty_nameservers
+
+    $res->empty_nameservers();
+
+Empties the list of nameservers.
+ 
 =head2 print
 
     $res->print;
@@ -343,6 +367,12 @@ Returns a string representation of the resolver state.
 
 Gets or sets the resolver search list.
 
+=head2 empty_searchlist
+
+    $res->empty_searchlist();
+
+Empties the searchlist.
+ 
 =head2 port
 
     print 'sending queries to port ', $res->port, "\n";
@@ -382,7 +412,7 @@ The default is 0.0.0.0, meaning any local address.
 Performs a background DNS query for the given name, i.e., sends a
 query packet to the first nameserver listed in C<< $res->nameservers >>
 and returns immediately without waiting for a response.  The program
-can then perform other tasks while waiting for a response from the 
+can then perform other tasks while waiting for a response from the
 nameserver.
 
 The argument list can be either a C<Net::DNS::Packet> object or a list
@@ -400,7 +430,7 @@ $res->bgisready >> or C<IO::Select> to find out if the socket is ready
 before reading it.
 
 bgsend does not support persistent sockets.
-
+bgsend does not support the usevc option (TCP).
 
 =head2 bgread
 
@@ -594,9 +624,9 @@ When set to true the answer and additional section of queries from
 secured zones will contain DNSKEY, NSEC and RRSIG records.
 
 Setting calling the dnssec method with a non-zero value will set the
-UDP packet size to the default value of 2048. If that is to small or
-to big for your environement you should call the udppacketsize()
-method immeditatly after.
+UDP packet size to the default value of 2048. If that is too small or
+too big for your environment you should call the udppacketsize()
+method immediately after.
 
    $res->dnssec(1);    # turns on DNSSEC and sets udp packetsize to 2048
    $res->udppacketsize(1028);   # lowers the UDP pakcet size
@@ -636,8 +666,8 @@ to 1.
     print "udppacketsize: ", $res->udppacketsize, "\n";
     $res->udppacketsize(2048);
 
-udppacketsize will set or get the packet size. If set to a value greater than 
-Net::DNS::PACKETSZ() an EDNS extension will be added indicating suppport for MTU path 
+udppacketsize will set or get the packet size. If set to a value greater than
+Net::DNS::PACKETSZ() an EDNS extension will be added indicating support for MTU path
 recovery.
 
 Default udppacketsize is Net::DNS::PACKETSZ() (512)
@@ -646,20 +676,20 @@ Default udppacketsize is Net::DNS::PACKETSZ() (512)
 
 Net::DNS::Resolver is actually an empty subclass.  At compile time a
 super class is chosen based on the current platform.  A side benefit of
-this allows for easy modification of the methods in Net::DNS::Resolver. 
-You simply add a method to the namespace!  
+this allows for easy modification of the methods in Net::DNS::Resolver.
+You simply add a method to the namespace!
 
 For example, if we wanted to cache lookups:
 
  package Net::DNS::Resolver;
- 
+
  my %cache;
- 
+
  sub search {
 	my ($self, @args) = @_;
-	
+
 	return $cache{@args} ||= $self->SUPER::search(@args);
- } 
+ }
 
 
 =head1 IPv6 transport
@@ -681,7 +711,7 @@ For example
 
     $res->nameservers('192.168.1.1', '192.168.2.2', '2001:610:240:0:53:0:0:3');
     $res->force_v4(1);
-    print join (" ",$res->nameserver());	    
+    print join (" ",$res->nameserver());
 
 Will print: 192.168.1.1 192.168.2.2
 
@@ -749,7 +779,7 @@ bgsend does not honor the usevc flag and only uses UDP for transport.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2002 Michael Fuhr. 
+Copyright (c) 1997-2002 Michael Fuhr.
 
 Portions Copyright (c) 2002-2004 Chris Reinhardt.
 Portions Copyright (c) 2005 Olaf M. Kolkman, NLnet Labs.
@@ -759,7 +789,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<perl(1)>, L<Net::DNS>, L<Net::DNS::Packet>, L<Net::DNS::Update>,
+L<perl>, L<Net::DNS>, L<Net::DNS::Packet>, L<Net::DNS::Update>,
 L<Net::DNS::Header>, L<Net::DNS::Question>, L<Net::DNS::RR>,
 L<resolver(5)>, RFC 1035, RFC 1034 Section 4.3.5
 
