@@ -1,33 +1,53 @@
 package Net::DNS::Resolver::Recurse;
 #
-# $Id: Recurse.pm 552 2005-12-23 09:29:12Z olaf $
+# $Id: Recurse.pm 1068 2012-12-06 10:38:51Z willem $
 #
 use strict;
 use Net::DNS::Resolver;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = (qw$LastChangedRevision: 552 $)[1];
+$VERSION = (qw$LastChangedRevision: 1068 $)[1];
 @ISA = qw(Net::DNS::Resolver);
 
+my %hardcodedhints
+	 = ( 'a.root-servers.net' => ['198.41.0.4'    , '2001:503:ba3e::2:30' ]
+	   , 'b.root-servers.net' => ['192.228.79.201']
+	   , 'c.root-servers.net' => ['192.33.4.12'   ]
+	   , 'd.root-servers.net' => ['128.8.10.90'   , '2001:500:2d::d'      ]
+	   , 'e.root-servers.net' => ['192.203.230.10']
+	   , 'f.root-servers.net' => ['192.5.5.241'   , '2001:500:2f::f'      ]
+	   , 'g.root-servers.net' => ['192.112.36.4'  ]
+	   , 'h.root-servers.net' => ['128.63.2.53'   , '2001:500:1::803f:235']
+	   , 'i.root-servers.net' => ['192.36.148.17' , '2001:7fe::53'        ]
+	   , 'j.root-servers.net' => ['192.58.128.30' , '2001:503:c27::2:30'  ]
+	   , 'k.root-servers.net' => ['193.0.14.129'  , '2001:7fd::1'         ]
+	   , 'l.root-servers.net' => ['199.7.83.42'   , '2001:500:3::42'      ]
+	   , 'm.root-servers.net' => ['202.12.27.33'  , '2001:dc3::35'        ]
+	   );
+
 sub hints {
   my $self = shift;
   my @hints = @_;
   print ";; hints(@hints)\n" if $self->{'debug'};
-  if (!@hints && $self->nameservers) {
-    $self->hints($self->nameservers);
+
+  if (!@hints && !$self->nameservers){
+	  return $self->hints( map { @{ $_ } } values %hardcodedhints )
+  }elsif (!@hints && $self->nameservers) {
+	  return $self->hints($self->nameservers);
   } else {
-    $self->nameservers(@hints);
+	  $self->nameservers(@hints);
   }
+
   print ";; verifying (root) zone...\n" if $self->{'debug'};
   # bind always asks one of the hint servers
   # for who it thinks is authoritative for
   # the (root) zone as a sanity check.
   # Nice idea.
-  
-  $self->recurse(1); 
-  my $packet=$self->query(".", "NS", "IN");
 
+  $self->recurse(1);
+  my $packet=$self->query(".", "NS", "IN");
+  $self->recurse(0);
   my %hints = ();
   if ($packet) {
     if (my @ans = $packet->answer) {
@@ -58,20 +78,25 @@ sub hints {
 	      push @{ $hints{$server} }, $rr->rdatastr;
 	    }
 	  }
-	  
-	} 
+
+	}
       }
     }
     foreach my $server (keys %hints) {
       if (!@{ $hints{$server} }) {
-	# Wipe the servers without lookups
-	delete $hints{$server};
+      	if (exists $hardcodedhints{ lc $server }) {
+	  # Not all root servers provide glue and we know the answers.
+	  $hints{$server} = $hardcodedhints{ lc $server };
+	} else {
+          # Wipe the servers without lookups
+          delete $hints{$server};
+	}
       }
     }
     $self->{'hints'} = \%hints;
   } else {
     $self->{'hints'} = {};
-  } 
+  }
   if (%{ $self->{'hints'} }) {
     if ($self->{'debug'}) {
       print ";; USING THE FOLLOWING HINT IPS:\n";
@@ -82,23 +107,26 @@ sub hints {
       }
     }
   } else {
-    warn "Server [".($self->nameservers)[0]."] did not give answers";
+    warn "Servers [". join " ",($self->nameservers),"] did not give answers";
+    print ";; Unsetting hints and nameservers, trying with hardcoded nameservers\n" if  $self->{'debug'};
+    print $self->empty_nameservers();
+    return $self->hints();
   }
-  
+
   # Disable recursion flag.
-  $self->recurse(0);
-  
+
+
   return $self->nameservers( map { @{ $_ } } values %{ $self->{'hints'} } );
 }
 
 
 sub recursion_callback {
 	my ($self, $sub) = @_;
-	
+
 	if ($sub && UNIVERSAL::isa($sub, 'CODE')) {
 		$self->{'callback'} = $sub;
 	}
-	
+
 	return $self->{'callback'};
 }
 
@@ -137,10 +165,10 @@ sub _dorecursion {
   if ( $depth > 255 ) {
       print ";; _dorecursion() Recursion too deep, aborting...\n" if
 	  $self->{'debug'};
-      $self->errorstring="Recursion to deep, abborted";
+      $self->errorstring("Recursion too deep, abborted");
       return undef;
   }
-  
+
   $known_zone =~ s/\.*$/./;
 
   # Get IPs from authorities
@@ -179,14 +207,14 @@ sub _dorecursion {
 		 $depth+1);         # depth
 	    @ans = $auth_packet->answer if $auth_packet;
 	}
-	
+
 	$auth_packet =
 	    $self->_dorecursion
 	    ($self->make_query_packet($ns,"A"),  # packet
 	     ".",               # known_zone
 	     $self->{'hints'},  # known_authorities
 	     $depth+1);         # depth
-	
+
 	push (@ans,$auth_packet->answer ) if $auth_packet;
 
         if ( @ans ) {
@@ -233,22 +261,22 @@ sub _dorecursion {
     print ";; _dorecursion() No authority information could be obtained.\n" if $self->{'debug'};
     return undef;
   }
-  
+
   # Cut the deck of IPs in a random place.
   print ";; _dorecursion() cutting deck of (".scalar(@ns).") authorities...\n" if $self->{'debug'};
   splice(@ns, 0, 0, splice(@ns, int(rand @ns)));
-  
-  
+
+
  LEVEL:  foreach my $levelns (@ns){
    print ";; _dorecursion() Trying nameserver [$levelns]\n" if $self->{'debug'};
    $self->nameservers($levelns);
-   
+
    if (my $packet = $self->send( $query_packet )) {
-     
+
      if ($self->{'callback'}) {
        $self->{'callback'}->($packet);
      }
-     
+
      my $of = undef;
      print ";; _dorecursion() Response received from [",$self->answerfrom,"]\n" if $self->{'debug'};
      if (my $status = $packet->header->rcode) {
@@ -318,7 +346,21 @@ sub _dorecursion {
      }
    }
  }
-  
+  # None of the authorities with IP worked. Are there still some without IP?
+  foreach my $ns (keys %{ $known_authorities }) {
+    if (scalar @{ $known_authorities->{$ns} }) {
+      delete $known_authorities->{$ns};
+    }
+  }
+  if (%{ $known_authorities }) {
+    print ";; _dorecursion() None of the authorities with IP worked, "
+                          . "retry with the others...\n" if $self->{'debug'};
+    return $self->_dorecursion( $query_packet
+                              , $known_zone
+			      , $known_authorities
+			      , $depth+1
+			      );
+  }
   return undef;
 }
 
@@ -351,11 +393,11 @@ the root (.) zone.
 
   $res->hints(@ips);
 
-If no hints are passed, the default nameserver is asked for the hints. 
+If no hints are passed, the default nameserver is asked for the hints.
 Normally these IPs can be obtained from the following location:
 
   ftp://ftp.internic.net/domain/named.root
-  
+
 =head2 recursion_callback
 
 This method is takes a code reference, which is then invoked each time a
@@ -364,11 +406,11 @@ dig's C<+trace> function:
 
  $res->recursion_callback(sub {
      my $packet = shift;
-		
+
      $_->print for $packet->additional;
-		
-     printf(";; Received %d bytes from %s\n\n", 
-         $packet->answersize, 
+
+     printf(";; Received %d bytes from %s\n\n",
+         $packet->answersize,
          $packet->answerfrom
      );
  });
@@ -406,7 +448,7 @@ Portions Copyright (c) 2005, Olaf M Kolkman.
 This module is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
-$Id: Recurse.pm 552 2005-12-23 09:29:12Z olaf $
+$Id: Recurse.pm 1068 2012-12-06 10:38:51Z willem $
 
 =cut
 
