@@ -1,10 +1,10 @@
 package Net::DNS::Text;
 
 #
-# $Id: Text.pm 1229 2014-07-09 07:07:42Z willem $
+# $Id: Text.pm 1068 2012-12-06 10:38:51Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1229 $)[1];
+$VERSION = (qw$LastChangedRevision: 1068 $)[1];
 
 
 =head1 NAME
@@ -42,22 +42,15 @@ use Carp;
 
 use constant ASCII => eval {
 	require Encode;
-	Encode::find_encoding('ascii');				# encoding object
-	1;
+	Encode::find_encoding('ASCII');				# return encoding object
 } || 0;
 
 use constant UTF8 => eval {
 	die if Encode::decode_utf8( chr(91) ) ne '[';		# not UTF-EBCDIC  [see UTR#16 3.6]
-	Encode::find_encoding('utf8');				# encoding object
-	1;
+	Encode::find_encoding('UTF8');				# return encoding object
 } || 0;
 
 
-# perlcc: eddress of encoding objects must be determined at runtime
-my $ascii = Encode::find_encoding('ascii') if ASCII;		# Osborn's Law:
-my $utf8  = Encode::find_encoding('utf8')  if UTF8;		# Variables won't; constants aren't.
-
-
 =head1 METHODS
 
 =head2 new
@@ -84,16 +77,18 @@ sub new {
 
 	local $_ = &_encode_utf8;
 
-	s/^\042(.*)\042$/$1/;					# strip paired quotes
-	s/^\047(.*)\047$/$1/;					# strip paired quotes
+	s/^([\042\047])(.*)\1$/$2/;				# strip paired quotes
 
-	s/\134\134/\134\060\071\062/g;				# disguise escaped escape
-	s/\134([\060-\071]{3})/$unescape{$1}/eg;		# numeric escape
+	s/\134\134/\134\066\066\066/g;				# disguise escaped escape
+
+	s/\134([\060-\062][\060-\071]{2})/$unescape{$1}/eg;	# numeric escape
+
+	s/\134\066\066\066/\134\134/g;				# reveal escaped escape
 	s/\134(.)/$1/g;						# character escape
 
 	while ( length $_ > 255 ) {
 		my $chunk = substr( $_, 0, 255 );		# carve into chunks
-		substr( $chunk, -length($1) ) = '' if $chunk =~ /.([\300-\377][\200-\277]*)$/;
+		substr( $chunk, -length($1) ) = '' if $chunk =~ /.([\300-\377][\200-\277]+)$/;
 		push @$self, $chunk;
 		substr( $_, 0, length $chunk ) = '';
 	}
@@ -121,7 +116,7 @@ the data buffer.
 =cut
 
 sub decode {
-	my $class  = shift;
+	my $self   = bless [], shift;
 	my $buffer = shift;					# reference to data buffer
 	my $offset = shift || 0;				# offset within buffer
 
@@ -129,7 +124,7 @@ sub decode {
 	my $next = ++$offset + $size;
 	croak 'corrupt wire-format data' if $next > length $$buffer;
 
-	my $self = bless [unpack( "\@$offset a$size", $$buffer )], $class;
+	push @$self, unpack "\@$offset a$size", $$buffer;
 
 	return wantarray ? ( $self, $next ) : $self;
 }
@@ -146,7 +141,7 @@ suitable for inclusion in a DNS packet buffer.
 
 sub encode {
 	my $self = shift;
-	join '', map pack( 'C a*', length $_, $_ ), @$self;
+	join '', map { pack 'C a*', length $_, $_ } @$self;
 }
 
 
@@ -158,6 +153,8 @@ Character string representation of the text object.
 
 =cut
 
+my %escape;							# precalculated ASCII/UTF-8 escape table
+
 sub value {
 	my $self = shift;
 	_decode_utf8( join '', @$self );
@@ -172,18 +169,18 @@ Conditionally quoted zone file representation of the text object.
 
 =cut
 
-my %escape;				## precalculated ASCII/UTF-8 escape table
+my $QQ = _decode_utf8( pack 'C', 34 );
 
 sub string {
 	my $self = shift;
 
-	my @s = map split( '', $_ ), @$self;			# escape non-printable
-	my $string = _decode_utf8( join '', map $escape{$_}, @s );
+	my @utf8 = map { s/([^\040\060-\132\141-\172])/$escape{$1}/eg; $_ } @$self;
+	my $string = _decode_utf8( join '', @utf8 );
 
-	return $string unless $string =~ /^$|[ \t\n\r\f]/;	# unquoted contiguous
+	# Note: Script-specific rules determine which Unicode characters match \s
+	return $string unless $string =~ /^$|\s|["\$'();@]/;	# unquoted contiguous
 
-	$string =~ s/\\([$();@])/$1/g;				# nothing special within quotes
-	join '', '"', $string, '"';				# quoted string
+	join '', $QQ, $string, $QQ;				# quoted string
 }
 
 
@@ -201,81 +198,74 @@ sub AUTOLOAD {				## Default method
 sub DESTROY { }				## Avoid tickling AUTOLOAD (in cleanup)
 
 
-sub _decode_utf8 {			## UTF-8 to perl internal encoding
-	my $s = shift;
+sub _decode_utf8 {
 
-	my $t = substr $s, 0, 0;				# pre-5.18 taint workaround
-	return $utf8->decode($s) . $t if UTF8;
+	return UTF8->decode(shift) if UTF8;
 
-	my $z = length $t;
-	return pack "a* x$z", $ascii->decode($s) if ASCII && not UTF8;
+	return ASCII->decode(shift) if ASCII && not UTF8;
 
-	# partial transliteration for non-ASCII character encodings
-	$s =~ tr
-	[\040-\176\000-\377]
-	[ !"#$%&'()*+,-./0-9:;<=>?@A-Z\[\\\]^_`a-z{|}~?] unless ASCII;
+	unless (ASCII) {
+		my $s = shift;
 
-	return $s;						# native 8-bit code
+		# partial transliteration for non-ASCII character encodings
+		$s =~ tr
+		[\055\040-\054\056-\176\000-\377]
+		[- !"#$%&'()*+,./0-9:;<=>?@A-Z\[\\\]^_`a-z{|}~?];
+
+		return $s;					# native 8-bit code
+	}
 }
 
 
-sub _encode_utf8 {			## perl internal encoding to UTF-8
-	my $s = shift;
+sub _encode_utf8 {
 
-	my $t = substr $s, 0, 0;				# pre-5.18 taint workaround
-	my $z = length $t;
-	return pack "a* x$z", $utf8->encode($s) if UTF8;
+	return UTF8->encode(shift) if UTF8;
 
-	return pack "a* x$z", $ascii->encode($s) if ASCII && not UTF8;
+	return ASCII->encode(shift) if ASCII && not UTF8;
 
-	# partial transliteration for non-ASCII character encodings
-	$s =~ tr
-	[ !"#$%&'()*+,-./0-9:;<=>?@A-Z\[\\\]^_`a-z{|}~]
-	[\040-\176] unless ASCII;
+	unless (ASCII) {
+		my $s = shift;
 
-	return $s;						# ASCII
+		# partial transliteration for non-ASCII character encodings
+		$s =~ tr
+		[- !"#$%&'()*+,./0-9:;<=>?@A-Z\[\\\]^_`a-z{|}~\000-\377]
+		[\055\040-\054\056-\176\077];
+
+		return $s;					# ASCII
+	}
 }
 
 
-%escape = eval {			## precalculated ASCII/UTF-8 escape table
+%escape = eval {				## precalculated ASCII/UTF-8 escape table
 	my %table;
 	my @C0 = ( 0 .. 31 );					# control characters
-	my @NA = UTF8 ? ( 192, 193, 216 .. 223, 245 .. 255 ) : ( 128 .. 255 );
+	my @NA = UTF8 ? ( 192, 193, 245 .. 255 ) : ( 128 .. 255 );
 
 	foreach ( 0 .. 255 ) {					# transparent
 		$table{pack( 'C', $_ )} = pack 'C', $_;
 	}
 
-	foreach ( 34, 36, 40, 41, 59, 64, 92 ) {		# escape character
-		$table{pack( 'C', $_ )} = pack 'C2', 92, $_;
+	foreach ( 34, 92 ) {					# escape character
+		$table{pack( 'C', $_ )} = pack 'C*', 92, $_;
 	}
 
-	foreach my $n ( @C0, 127, @NA ) {			# \ddd
-		my $codepoint = sprintf( '%03u', $n );
-
-		# partial transliteration for non-ASCII character encodings
-		$codepoint =~ tr [0-9] [\060-\071];
-
-		$table{pack( 'C', $n )} = pack 'C a3', 92, $codepoint;
+	foreach ( @C0, 127, @NA ) {				# \ddd
+		$table{pack( 'C', $_ )} = _encode_utf8 sprintf( '\\%03u', $_ );
 	}
 
 	return %table;
 };
 
 
-%unescape = eval {			## precalculated numeric escape table
+%unescape = eval {				## precalculated numeric escape table
 	my %table;
 
-	foreach my $n ( 0 .. 255 ) {
-		my $key = sprintf( '%03u', $n );
-
-		# partial transliteration for non-ASCII character encodings
-		$key =~ tr [0-9] [\060-\071];
-
-		$table{$key} = pack 'C', $n;
-		$table{$key} = pack 'C2', 92, $n if $n == 92;	# escaped escape
+	foreach ( 0 .. 255 ) {
+		$table{_encode_utf8 sprintf( '%03u', $_ )} = pack 'C', $_;
 	}
 
+	$table{_encode_utf8('092')} = pack 'Ca*', 92, _encode_utf8 '666';
+
 	return %table;
 };
 
